@@ -33,17 +33,12 @@
 
 #include "as_generic.h"
 
-// Version information
-#define _AS_VERSION_CPP_AS_HEADER_
-#include "as_version.cpp"
-#undef  _AS_VERSION_CPP_AS_HEADER_
-
 
 // Construct a Prototype object
 Prototype::Prototype()
 {
     // For display of a prototype implementation
-    QString Namever = QString("AS Accounting System") + ' ' + asgui_version.v_short;
+    QString Namever = QString("AS Accounting System");
     m_pProtomsg = new QMessageBox(Namever,
         QObject::trUtf8("This method is not implemented yet."),
         QMessageBox::NoIcon, QMessageBox::Ok | QMessageBox::Default,
